==> openGion6.6.0.1_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GEA08S.sql <==
/****************************************************************************/
/* GEA08 ( 項目名称定義(ﾗﾍﾞﾙ) )                                             */
/*                                                                          */
/* Created : 2016/10/27 10:57:15                                            */
/****************************************************************************/

CREATE TABLE GEA08 (
   SYSTEM_ID        varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID   */
 , LANG             varchar           (    2 )                  NOT NULL            /*  20 言語     */
 , CLM              varchar           (   30 )                  NOT NULL            /*  30 項目     */
 , NAME_JA          varchar           (  200 )                                      /*  40 名称     */
 , SNAME            varchar           (   60 )                                      /*  50 名前(短) */
 , LNAME            varchar           (  500 )                                      /*  60 名前(長) */
 , DESCRIPTION      varchar           ( 4000 )                                      /*  70 概要説明 */
 , KBLBL            varchar           (    1 )                  NOT NULL            /*  80 ﾗﾍﾞﾙ区分 */
 , COMMENTS         varchar           (  500 )                                      /*  90 ｺﾒﾝﾄ     */
 , CDKH             varchar           (    1 )                                      /* 100 改廃ｺｰﾄﾞ */
 , FGLOAD           varchar           (    1 )      DEFAULT 0   NOT NULL            /* 110 読込F    */
 , KBSAKU           varchar           (    1 )      DEFAULT 1   NOT NULL            /* 120 作成区分 */
 , RELEASE_NOTES    varchar           (  120 )                                      /* 130 ﾘﾘｰｽﾉｰﾄ  */
 , RDC_CODE         varchar           (   20 )                                      /* 190 設変番号 */
 , UNIQ             int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ              varchar           (    1 )      DEFAULT 1   NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET            varchar           (   14 )                                      /* 820 登録日時 */
 , PGSET            varchar           (   10 )                                      /* 830 作成PG   */
 , PGPSET           varchar           (   10 )                                      /* 840 作成親PG */
 , USRSET           varchar           (   10 )                                      /* 850 作成社員 */
 , DYUPD            varchar           (   14 )                                      /* 860 更新日時 */
 , PGUPD            varchar           (   10 )                                      /* 870 更新PG   */
 , PGPUPD           varchar           (   10 )                                      /* 880 更新親PG */
 , USRUPD           varchar           (   10 )                                      /* 890 更新者   */
);

==> openGion7.0.0.0_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GEA08S.sql <==
/****************************************************************************/
/* GEA08 ( 項目名称定義(ﾗﾍﾞﾙ) )                                             */
/*                                                                          */
/* Created : 2018/09/28 16:03:40                                            */
/****************************************************************************/

CREATE TABLE GEA08 (
   SYSTEM_ID        varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID   */
 , LANG             varchar           (    2 )                  NOT NULL            /*  20 言語     */
 , CLM              varchar           (   50 )                  NOT NULL            /*  30 項目     */
 , NAME_JA          varchar           (  200 )                                      /*  40 名称     */
 , SNAME            varchar           (   60 )                                      /*  50 名前(短) */
 , LNAME            varchar           (  500 )                                      /*  60 名前(長) */
 , DESCRIPTION      varchar           ( 4000 )                                      /*  70 概要説明 */
 , KBLBL            varchar           (    1 )                  NOT NULL            /*  80 ﾗﾍﾞﾙ区分 */
 , COMMENTS         varchar           (  500 )                                      /*  90 ｺﾒﾝﾄ     */
 , CDKH             varchar           (    1 )                                      /* 100 改廃ｺｰﾄﾞ */
 , FGLOAD           varchar           (    1 )      DEFAULT '0' NOT NULL            /* 110 読込F    */
 , KBSAKU           varchar           (    1 )      DEFAULT '1' NOT NULL            /* 120 作成区分 */
 , RELEASE_NOTES    varchar           (  120 )                                      /* 130 ﾘﾘｰｽﾉｰﾄ  */
 , RDC_CODE         varchar           (   20 )                                      /* 190 設変番号 */
 , UNIQ             int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ              varchar           (    1 )      DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET            varchar           (   14 )                                      /* 820 登録日時 */
 , PGSET            varchar           (   10 )                                      /* 830 作成PG   */
 , PGPSET           varchar           (   10 )                                      /* 840 作成親PG */
 , USRSET           varchar           (   10 )                                      /* 850 作成者   */
 , DYUPD            varchar           (   14 )                                      /* 860 更新日時 */
 , PGUPD            varchar           (   10 )                                      /* 870 更新PG   */
 , PGPUPD           varchar           (   10 )                                      /* 880 更新親PG */
 , USRUPD           varchar           (   10 )                                      /* 890 更新者   */
);
